@@ -5,17 +5,19 @@ use warnings;
 use strict;
 use Scalar::Util qw(reftype);
 
+=encoding UTF-8
+
 =head1 NAME
 
 Algorithm::SixDegrees - Find a path through linked elements in a set
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 our $ERROR = '';
 
 =head1 SYNOPSIS
@@ -404,7 +406,7 @@ one-element list.
 
 =head1 AUTHOR
 
-Pete Krawczyk, C<< <petek@cpan.org> >>
+Peter Krawczyk, C<< <petek@cpan.org> >>
 
 =head1 BUGS
 
@@ -415,6 +417,10 @@ be notified of progress on your bug as I make changes.
 
 =head1 ACKNOWLEDGEMENTS
 
+Thank you to Slaven Rezić and Peter John Acklam for bug reports.
+Apologies it took so long to see and fix them. (So much for
+notifications...)
+
 Andy Lester and Ricardo Signes wrote Module::Starter, which helped
 get the framework up and running fairly quickly.
 
@@ -425,7 +431,7 @@ into this module.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Pete Krawczyk, All Rights Reserved.
+Copyright 2005-2020 Peter Krawczyk, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
